# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/get/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/get/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/post/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/get/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3814
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictStr
from ourskyai_sda_api.models.v1_satellite_target import V1SatelliteTarget

class V1OrganizationTarget(BaseModel):
    """
    V1OrganizationTarget
    """
    id: StrictStr = Field(...)
    satellite_target: V1SatelliteTarget = Field(..., alias="satelliteTarget")
    created_by: StrictStr = Field(..., alias="createdBy")
    created_at: datetime = Field(..., alias="createdAt")
    __properties = ["id", "satelliteTarget", "createdBy", "createdAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1OrganizationTarget:
        """Create an instance of V1OrganizationTarget from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of satellite_target
        if self.satellite_target:
            _dict['satelliteTarget'] = self.satellite_target.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1OrganizationTarget:
        """Create an instance of V1OrganizationTarget from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1OrganizationTarget.parse_obj(obj)

        _obj = V1OrganizationTarget.parse_obj({
            "id": obj.get("id"),
            "satellite_target": V1SatelliteTarget.from_dict(obj.get("satelliteTarget")) if obj.get("satelliteTarget") is not None else None,
            "created_by": obj.get("createdBy"),
            "created_at": obj.get("createdAt")
        })
        return _obj


